==> 1.0.0.tar.gz: ios/Classes/PlateformViews/VideoFeedViewFactory.swift <==
//
//  VideoFeedViewFactory.swift
//  fw_flutter_sdk
//
//  Created by Jeff Zheng on 2022/2/21.
//

import Foundation
import Flutter
import FireworkVideo

class VideoFeedViewFactory: NSObject, FlutterPlatformViewFactory {
    private var messenger: FlutterBinaryMessenger
    
    init(messenger: FlutterBinaryMessenger) {
        self.messenger = messenger
        super.init()
    }

    func create(
        withFrame frame: CGRect,
        viewIdentifier viewId: Int64,
        arguments args: Any?
    ) -> FlutterPlatformView {
        return VideoFeedContainerView(
            frame: frame,
            viewIdentifier: viewId,
            arguments: args,
            binaryMessenger: messenger)
    }
    
    public func createArgsCodec() -> FlutterMessageCodec & NSObjectProtocol {
          return FlutterStandardMessageCodec.sharedInstance()
    }
}

private class VideoFeedContainerView: NSObject, FlutterPlatformView, VideoFeedViewDelegate {
    private var _view: UIView
    var channel: FlutterMethodChannel! = nil
    var videoFeed: VideoFeed!

    init(
        frame: CGRect,
        viewIdentifier viewId: Int64,
        arguments args: Any?,
        binaryMessenger messenger: FlutterBinaryMessenger
    ) {
        let channelName = String(format: FWChannelName.FireworkVideoFeedModule.rawValue, arguments: [viewId])
        channel = FlutterMethodChannel.init(name: channelName, binaryMessenger: messenger)
        
        _view = UIView()
        super.init()
        // iOS views can be created here
        createVideoFeedView(view: _view, args: args as? Dictionary<String, AnyObject>)
        setMethodCallHandler(channel)
    }
    
    deinit {
        
    }

    func createVideoFeedView(view _view: UIView, args _args: Dictionary<String, AnyObject>?) {
        videoFeed = VideoFeed()
        videoFeed.translatesAutoresizingMaskIntoConstraints = false
        videoFeed.delegate = self
        if let config = _args {
            videoFeed.sourceType = RCTConvert.videoFeedSourceType(config["source"] as? String)
            if let channel = config["channel"] as? String {
                videoFeed.channel = channel
            }
            if let playlist = config["playlist"] as? String {
                videoFeed.playlist = playlist
            }
            if let playlistGroup = config["playlistGroup"] as? String {
                videoFeed.playlistGroup = playlistGroup
            }
            videoFeed.mode = RCTConvert.videoFeedMode(config["mode"] as? String)
            videoFeed.feedViewConfig = JsonHelper.fromDictionary(config["videoFeedConfiguration"] as? [String : AnyObject], type: VideoFeedConfiguration.self)
            videoFeed.playerViewConfig = JsonHelper.fromDictionary(config["videoPlayerConfiguration"] as? [String : AnyObject], type: VideoPlayerConfiguration.self)
        }

        _view.addSubview(videoFeed)
        let constraints = videoFeed.constraints(equalTo: _view)
        NSLayoutConstraint.activate(
            constraints
        )
    }
    
    func setMethodCallHandler(_ channel: FlutterMethodChannel) {
        channel.setMethodCallHandler { [weak self] (call: FlutterMethodCall, result: @escaping FlutterResult) -> Void in
            switch call.method {
            case FWVideoFeedMethodName.setVideoFeedConfiguration.rawValue:
                self?.setVideoFeedConfiguration(call.arguments as? Dictionary<String, AnyObject>)
                result(nil)
            case FWVideoFeedMethodName.setVideoPlayerConfiguration.rawValue:
                self?.setVideoPlayerConfiguration(call.arguments as? Dictionary<String, AnyObject>)
                result(nil)
            case FWVideoFeedMethodName.refresh.rawValue:
                self?.videoFeed.refresh()
                result(nil)
            default:
                result(FlutterMethodNotImplemented)
                break
            }
        }
    }
    
    func setVideoFeedConfiguration(_ config: Dictionary<String, AnyObject>?) {
        videoFeed.feedViewConfig = JsonHelper.fromDictionary(config, type: VideoFeedConfiguration.self)
    }
    
    func setVideoPlayerConfiguration(_ config: Dictionary<String, AnyObject>?) {
        videoFeed.playerViewConfig = JsonHelper.fromDictionary(config, type: VideoPlayerConfiguration.self)
    }
    
    //MARK: - FlutterPlatformView
    func view() -> UIView {
        return _view
    }
    
    
    //MARK: - VideoFeedViewDelegate
    func videoFeedDidLoadFeed(_ view: VideoFeed) {
        channel.invokeMethod("onVideoFeedLoadFinished", arguments: nil)
    }
    
    func videoFeed(_ view: VideoFeed, didFailToLoadFeed error: VideoFeedError) {
        channel.invokeMethod("onVideoFeedLoadFinished", arguments: error.jsObject)
    }
}

==> 1.3.0.tar.gz: ios/Classes/PlateformViews/VideoFeedViewFactory.swift <==
//
//  VideoFeedViewFactory.swift
//  fw_flutter_sdk
//
//  Created by Jeff Zheng on 2022/2/21.
//

import Foundation
import Flutter
import FireworkVideo

class VideoFeedViewFactory: NSObject, FlutterPlatformViewFactory {
    private var messenger: FlutterBinaryMessenger
    
    init(messenger: FlutterBinaryMessenger) {
        self.messenger = messenger
        super.init()
    }

    func create(
        withFrame frame: CGRect,
        viewIdentifier viewId: Int64,
        arguments args: Any?
    ) -> FlutterPlatformView {
        return VideoFeedContainerView(
            frame: frame,
            viewIdentifier: viewId,
            arguments: args,
            binaryMessenger: messenger)
    }
    
    public func createArgsCodec() -> FlutterMessageCodec & NSObjectProtocol {
          return FlutterStandardMessageCodec.sharedInstance()
    }
}

private class VideoFeedContainerView: NSObject, FlutterPlatformView, VideoFeedViewDelegate {
    private var _view: UIView
    var methodChannel: FlutterMethodChannel
    var videoFeed: VideoFeed!

    init(
        frame: CGRect,
        viewIdentifier viewId: Int64,
        arguments args: Any?,
        binaryMessenger messenger: FlutterBinaryMessenger
    ) {
        let channelName = String(format: FWChannelName.FireworkVideoFeedModule.rawValue, arguments: [viewId])
        methodChannel = FlutterMethodChannel.init(name: channelName, binaryMessenger: messenger)
        
        _view = UIView()
        super.init()
        // iOS views can be created here
        createVideoFeedView(view: _view, args: args as? Dictionary<String, AnyObject>)
        setMethodCallHandler(methodChannel)
    }
    
    deinit {
        
    }

    func createVideoFeedView(view _view: UIView, args _args: Dictionary<String, AnyObject>?) {
        videoFeed = VideoFeed()
        videoFeed.translatesAutoresizingMaskIntoConstraints = false
        videoFeed.delegate = self
        if let arguments = _args {
            videoFeed.sourceType = RCTConvert.videoFeedSourceType(arguments["source"] as? String)
            if let channel = arguments["channel"] as? String {
                videoFeed.channel = channel
            }
            if let playlist = arguments["playlist"] as? String {
                videoFeed.playlist = playlist
            }
            if let playlistGroup = arguments["playlistGroup"] as? String {
                videoFeed.playlistGroup = playlistGroup
            }
            if let dynamicContentParameters = arguments["dynamicContentParameters"] as? [String: [String]] {
                videoFeed.dynamicContentParameters = dynamicContentParameters
            }
            videoFeed.mode = RCTConvert.videoFeedMode(arguments["mode"] as? String)
            videoFeed.feedViewConfig = JsonHelper.fromDictionary(arguments["videoFeedConfiguration"] as? [String : AnyObject], type: VideoFeedConfiguration.self)
            videoFeed.playerViewConfig = JsonHelper.fromDictionary(arguments["videoPlayerConfiguration"] as? [String : AnyObject], type: VideoPlayerConfiguration.self)
        }

        _view.addSubview(videoFeed)
        let constraints = videoFeed.constraints(equalTo: _view)
        NSLayoutConstraint.activate(
            constraints
        )
    }
    
    func setMethodCallHandler(_ channel: FlutterMethodChannel) {
        channel.setMethodCallHandler { [weak self] (call: FlutterMethodCall, result: @escaping FlutterResult) -> Void in
            switch call.method {
            case FWVideoFeedMethodName.setVideoFeedConfiguration.rawValue:
                self?.setVideoFeedConfiguration(call.arguments as? Dictionary<String, AnyObject>)
                result(nil)
            case FWVideoFeedMethodName.setVideoPlayerConfiguration.rawValue:
                self?.setVideoPlayerConfiguration(call.arguments as? Dictionary<String, AnyObject>)
                result(nil)
            case FWVideoFeedMethodName.refresh.rawValue:
                self?.videoFeed.refresh()
                result(nil)
            default:
                result(FlutterMethodNotImplemented)
                break
            }
        }
    }
    
    func setVideoFeedConfiguration(_ config: Dictionary<String, AnyObject>?) {
        videoFeed.feedViewConfig = JsonHelper.fromDictionary(config, type: VideoFeedConfiguration.self)
    }
    
    func setVideoPlayerConfiguration(_ config: Dictionary<String, AnyObject>?) {
        videoFeed.playerViewConfig = JsonHelper.fromDictionary(config, type: VideoPlayerConfiguration.self)
    }
    
    //MARK: - FlutterPlatformView
    func view() -> UIView {
        return _view
    }
    
    
    //MARK: - VideoFeedViewDelegate
    func videoFeedDidLoadFeed(_ view: VideoFeed) {
        methodChannel.invokeMethod(VideoFeedEventName.onVideoFeedLoadFinished.rawValue, arguments: nil)
    }
    
    func videoFeed(_ view: VideoFeed, didFailToLoadFeed error: VideoFeedError) {
        methodChannel.invokeMethod(VideoFeedEventName.onVideoFeedLoadFinished.rawValue, arguments: error.jsObject)
    }
}
